@@ -1,12 +1,14 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #pragma once
 
+#include <QDir>
 #include <QObject>
+
 namespace KIdentityManagement
 {
 class IdentityManager;
@@ -22,11 +24,17 @@ public:
 private Q_SLOTS:
     void cleanupTestCase();
     void initTestCase();
+    void init();
+    void cleanup();
     void shouldHaveDefaultValue();
-    void testGenerateCryptoMessages();
+    void testGenerateCryptoMessagesAutocrypt_data();
+    void testGenerateCryptoMessagesAutocrypt();
+    void testGenerateCryptoMessagesAutocryptSMime();
     void testAutoSaveMessage();
+    void testAutocryptKey();
 private:
     KIdentityManagement::IdentityManager *mIdentMan = nullptr;
     KIdentityManagement::IdentityCombo *mIdentCombo = nullptr;
+    QDir autocryptDir;
 };
 
