@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class InfoPartTest : public QObject
     Q_OBJECT
 public:
     explicit InfoPartTest(QObject *parent = nullptr);
-    ~InfoPartTest();
+    ~InfoPartTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
