@@ -23,7 +23,7 @@ class ReplyStrategyTest : public QObject
 
 public:
     explicit ReplyStrategyTest(QObject *parent = nullptr);
-    ~ReplyStrategyTest();
+    ~ReplyStrategyTest() override;
 
 private Q_SLOTS:
     void initTestCase();
@@ -35,6 +35,6 @@ private Q_SLOTS:
 private:
     KMime::Message::Ptr makeReply(const KMime::Message::Ptr &original, const MessageComposer::ReplyStrategy strategy);
 
-    KIdentityManagement::IdentityManager *mIdentityManager;
+    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
 };
 
