@@ -24,10 +24,9 @@
 
 #include <MessageCore/StringUtil>
 
-#include <AkonadiCore/itemfetchjob.h>
+#include <Akonadi/ItemFetchJob>
+#include <KIO/JobUiDelegate>
 #include <QIcon>
-#include <kio/jobuidelegate.h>
-#include <kio_version.h>
 
 #include <QMenu>
 #include <QPointer>
@@ -52,8 +51,8 @@
 #include "attachment/attachmentfrommimecontentjob.h"
 #include "attachment/attachmentfromurljob.h"
 #include "messagecore/attachmentupdatejob.h"
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
-#include <Akonadi/Contact/EmailAddressSelectionWidget>
+#include <Akonadi/EmailAddressSelectionDialog>
+#include <Akonadi/EmailAddressSelectionWidget>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
@@ -70,11 +69,11 @@
 using namespace MessageComposer;
 using namespace MessageCore;
 
-class Q_DECL_HIDDEN MessageComposer::AttachmentControllerBase::Private
+class MessageComposer::AttachmentControllerBase::AttachmentControllerBasePrivate
 {
 public:
-    Private(AttachmentControllerBase *qq);
-    ~Private();
+    AttachmentControllerBasePrivate(AttachmentControllerBase *qq);
+    ~AttachmentControllerBasePrivate();
 
     void attachmentRemoved(const AttachmentPart::Ptr &part); // slot
     void compressJobResult(KJob *job); // slot
@@ -132,14 +131,12 @@ public:
     bool signEnabled = false;
 };
 
-AttachmentControllerBase::Private::Private(AttachmentControllerBase *qq)
+AttachmentControllerBase::AttachmentControllerBasePrivate::AttachmentControllerBasePrivate(AttachmentControllerBase *qq)
     : q(qq)
 {
 }
 
-AttachmentControllerBase::Private::~Private()
-{
-}
+AttachmentControllerBase::AttachmentControllerBasePrivate::~AttachmentControllerBasePrivate() = default;
 
 void AttachmentControllerBase::setSelectedParts(const AttachmentPart::List &selectedParts)
 {
@@ -159,12 +156,12 @@ void AttachmentControllerBase::setSelectedParts(const AttachmentPart::List &sele
     d->propertiesContextAction->setEnabled(selectedCount == 1);
 }
 
-void AttachmentControllerBase::Private::attachmentRemoved(const AttachmentPart::Ptr &part)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::attachmentRemoved(const AttachmentPart::Ptr &part)
 {
     uncompressedParts.remove(part);
 }
 
-void AttachmentControllerBase::Private::compressJobResult(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::compressJobResult(KJob *job)
 {
     if (job->error()) {
         KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to compress attachment"));
@@ -198,7 +195,7 @@ void AttachmentControllerBase::Private::compressJobResult(KJob *job)
     }
 }
 
-void AttachmentControllerBase::Private::loadJobResult(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::loadJobResult(KJob *job)
 {
     if (job->error()) {
         KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to attach file"));
@@ -211,7 +208,7 @@ void AttachmentControllerBase::Private::loadJobResult(KJob *job)
     q->addAttachment(part);
 }
 
-void AttachmentControllerBase::Private::openSelectedAttachments()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::openSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
     for (const AttachmentPart::Ptr &part : std::as_const(selectedParts)) {
@@ -219,7 +216,7 @@ void AttachmentControllerBase::Private::openSelectedAttachments()
     }
 }
 
-void AttachmentControllerBase::Private::viewSelectedAttachments()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::viewSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
     for (const AttachmentPart::Ptr &part : std::as_const(selectedParts)) {
@@ -227,19 +224,19 @@ void AttachmentControllerBase::Private::viewSelectedAttachments()
     }
 }
 
-void AttachmentControllerBase::Private::editSelectedAttachment()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::editSelectedAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
     q->editAttachment(selectedParts.constFirst(), MessageViewer::EditorWatcher::NoOpenWithDialog);
 }
 
-void AttachmentControllerBase::Private::editSelectedAttachmentWith()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::editSelectedAttachmentWith()
 {
     Q_ASSERT(selectedParts.count() == 1);
     q->editAttachment(selectedParts.constFirst(), MessageViewer::EditorWatcher::OpenWithDialog);
 }
 
-void AttachmentControllerBase::Private::removeSelectedAttachments()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::removeSelectedAttachments()
 {
     Q_ASSERT(selectedParts.count() >= 1);
     // We must store list, otherwise when we remove it changes selectedParts (as selection changed) => it will crash.
@@ -249,19 +246,19 @@ void AttachmentControllerBase::Private::removeSelectedAttachments()
     }
 }
 
-void AttachmentControllerBase::Private::saveSelectedAttachmentAs()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::saveSelectedAttachmentAs()
 {
     Q_ASSERT(selectedParts.count() == 1);
     q->saveAttachmentAs(selectedParts.constFirst());
 }
 
-void AttachmentControllerBase::Private::selectedAttachmentProperties()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::selectedAttachmentProperties()
 {
     Q_ASSERT(selectedParts.count() == 1);
     q->attachmentProperties(selectedParts.constFirst());
 }
 
-void AttachmentControllerBase::Private::reloadAttachment()
+void AttachmentControllerBase::AttachmentControllerBasePrivate::reloadAttachment()
 {
     Q_ASSERT(selectedParts.count() == 1);
     auto ajob = new AttachmentUpdateJob(selectedParts.constFirst(), q);
@@ -271,7 +268,7 @@ void AttachmentControllerBase::Private::reloadAttachment()
     ajob->start();
 }
 
-void AttachmentControllerBase::Private::updateJobResult(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::updateJobResult(KJob *job)
 {
     if (job->error()) {
         KMessageBox::sorry(wParent, job->errorString(), i18n("Failed to reload attachment"));
@@ -290,7 +287,7 @@ void AttachmentControllerBase::Private::updateJobResult(KJob *job)
     }
 }
 
-void AttachmentControllerBase::Private::editDone(MessageViewer::EditorWatcher *watcher)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::editDone(MessageViewer::EditorWatcher *watcher)
 {
     AttachmentPart::Ptr part = editorPart.take(watcher);
     Q_ASSERT(part);
@@ -311,7 +308,7 @@ void AttachmentControllerBase::Private::editDone(MessageViewer::EditorWatcher *w
     // The watcher deletes itself.
 }
 
-void AttachmentControllerBase::Private::createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::createOpenWithMenu(QMenu *topMenu, const AttachmentPart::Ptr &part)
 {
     const QString contentTypeStr = QString::fromLatin1(part->mimeType());
     const KService::List offers = KFileItemActions::associatedApplications(QStringList() << contentTypeStr);
@@ -371,7 +368,7 @@ void AttachmentControllerBase::exportPublicKey(const QString &fingerprint)
     ajob->start();
 }
 
-void AttachmentControllerBase::Private::attachPublicKeyJobResult(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::attachPublicKeyJobResult(KJob *job)
 {
     // The only reason we can't use loadJobResult() and need a separate method
     // is that we want to show the proper caption ("public key" instead of "file")...
@@ -387,7 +384,7 @@ void AttachmentControllerBase::Private::attachPublicKeyJobResult(KJob *job)
     q->addAttachment(part);
 }
 
-void AttachmentControllerBase::Private::attachVcardFromAddressBook(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::attachVcardFromAddressBook(KJob *job)
 {
     if (job->error()) {
         qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get vCard";
@@ -400,7 +397,7 @@ void AttachmentControllerBase::Private::attachVcardFromAddressBook(KJob *job)
     q->addAttachment(part);
 }
 
-void AttachmentControllerBase::Private::attachClipBoardElement(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::attachClipBoardElement(KJob *job)
 {
     if (job->error()) {
         qCDebug(MESSAGECOMPOSER_LOG) << " Error during when get try to attach text from clipboard";
@@ -432,7 +429,7 @@ static QTemporaryFile *dumpAttachmentToTempFile(const AttachmentPart::Ptr &part)
 
 AttachmentControllerBase::AttachmentControllerBase(MessageComposer::AttachmentModel *model, QWidget *wParent, KActionCollection *actionCollection)
     : QObject(wParent)
-    , d(new Private(this))
+    , d(new AttachmentControllerBasePrivate(this))
 {
     d->model = model;
     connect(model, &MessageComposer::AttachmentModel::attachUrlsRequested, this, &AttachmentControllerBase::addAttachments);
@@ -447,10 +444,7 @@ AttachmentControllerBase::AttachmentControllerBase(MessageComposer::AttachmentMo
     d->mActionCollection = actionCollection;
 }
 
-AttachmentControllerBase::~AttachmentControllerBase()
-{
-    delete d;
-}
+AttachmentControllerBase::~AttachmentControllerBase() = default;
 
 void AttachmentControllerBase::createActions()
 {
@@ -735,7 +729,7 @@ void AttachmentControllerBase::viewAttachment(const AttachmentPart::Ptr &part)
     attachmentJob->start();
 }
 
-void AttachmentControllerBase::Private::slotAttachmentContentCreated(KJob *job)
+void AttachmentControllerBase::AttachmentControllerBasePrivate::slotAttachmentContentCreated(KJob *job)
 {
     if (!job->error()) {
         const MessageComposer::AttachmentJob *const attachmentJob = qobject_cast<MessageComposer::AttachmentJob *>(job);
@@ -850,7 +844,9 @@ void AttachmentControllerBase::attachDirectory(const QUrl &url)
 {
     const int rc = KMessageBox::warningYesNo(d->wParent,
                                              i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                                             i18nc("@title:window", "Attach directory"));
+                                             i18nc("@title:window", "Attach directory"),
+                                             KGuiItem(i18nc("@action:button", "Attach")),
+                                             KStandardGuiItem::cancel());
     if (rc == KMessageBox::Yes) {
         addAttachment(url);
     }
@@ -906,7 +902,9 @@ void AttachmentControllerBase::showAddAttachmentFileDialog()
             if (mimeType.name() == QLatin1String("inode/directory")) {
                 const int rc = KMessageBox::warningYesNo(d->wParent,
                                                          i18n("Do you really want to attach this directory \"%1\"?", url.toLocalFile()),
-                                                         i18nc("@title:window", "Attach directory"));
+                                                         i18nc("@title:window", "Attach directory"),
+                                                         KGuiItem(i18nc("@action:button", "Attach")),
+                                                         KStandardGuiItem::cancel());
                 if (rc == KMessageBox::Yes) {
                     addAttachment(urlWithEncoding);
                 }
