@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,7 +12,7 @@
 #include <QTextBlock>
 using namespace MessageComposer;
 
-class Q_DECL_HIDDEN RichTextComposerSignatures::RichTextComposerSignaturesPrivate
+class RichTextComposerSignatures::RichTextComposerSignaturesPrivate
 {
 public:
     RichTextComposerSignaturesPrivate(RichTextComposerNg *composer)
@@ -31,10 +31,7 @@ RichTextComposerSignatures::RichTextComposerSignatures(MessageComposer::RichText
 {
 }
 
-RichTextComposerSignatures::~RichTextComposerSignatures()
-{
-    delete d;
-}
+RichTextComposerSignatures::~RichTextComposerSignatures() = default;
 
 void RichTextComposerSignatures::RichTextComposerSignaturesPrivate::cleanWhitespaceHelper(const QRegExp &regExp,
                                                                                           const QString &newText,
@@ -42,7 +39,7 @@ void RichTextComposerSignatures::RichTextComposerSignaturesPrivate::cleanWhitesp
 {
     int currentSearchPosition = 0;
 
-    forever {
+    for (;;) {
         // Find the text
         const QString text = richTextComposer->document()->toPlainText();
         const int currentMatch = regExp.indexIn(text, currentSearchPosition);
@@ -108,7 +105,7 @@ QVector<QPair<int, int>> RichTextComposerSignatures::RichTextComposerSignaturesP
         QString sigText = sig.toPlainText();
 
         int currentSearchPosition = 0;
-        forever {
+        for (;;) {
             // Find the next occurrence of the signature text
             const QString text = richTextComposer->document()->toPlainText();
             const int currentMatch = text.indexOf(sigText, currentSearchPosition);
@@ -136,7 +133,7 @@ bool RichTextComposerSignatures::replaceSignature(const KIdentityManagement::Sig
     QTextCursor cursor(d->richTextComposer->document());
     cursor.beginEditBlock();
     int currentSearchPosition = 0;
-    forever {
+    for (;;) {
         // Find the next occurrence of the signature text
         const QString text = d->richTextComposer->document()->toPlainText();
         const int currentMatch = text.indexOf(oldSigText, currentSearchPosition);
@@ -146,7 +143,6 @@ bool RichTextComposerSignatures::replaceSignature(const KIdentityManagement::Sig
         }
 
         // Select the signature
-        QTextCursor cursor(d->richTextComposer->document());
         cursor.setPosition(currentMatch);
 
         // If the new signature is completely empty, we also want to remove the
