@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,12 +9,12 @@
 #pragma once
 
 #include "messagecomposer_export.h"
-#include <kmime/kmime_mdn.h>
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
+#include <KMime/MDN>
 
-#include <Akonadi/KMime/MessageStatus>
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <Akonadi/MessageStatus>
 #include <QVector>
 
 namespace KIdentityManagement
@@ -96,7 +96,7 @@ public:
     Q_REQUIRED_RESULT KMime::Message::Ptr createResend();
 
     /** Create a new message that is a delivery receipt of this message,
-      filling required header fileds with the proper values. The
+      filling required header fields with the proper values. The
       returned message is not stored in any folder. */
     Q_REQUIRED_RESULT KMime::Message::Ptr createDeliveryReceipt();
 
