@@ -1,11 +1,10 @@
 /*  This file is part of the KDE project
-    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGECOMPOSERPRIVATE_EXPORT_H
-#define MESSAGECOMPOSERPRIVATE_EXPORT_H
+#pragma once
 
 #include "messagecomposer_export.h"
 
@@ -18,4 +17,3 @@
 #define MESSAGECOMPOSER_TESTS_EXPORT
 #endif
 
-#endif
