@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,6 +22,7 @@ using namespace MessageComposer;
 
 SendLaterDialog::SendLaterDialog(SendLaterInfo *info, QWidget *parent)
     : QDialog(parent)
+    , mSendLaterWidget(new Ui::SendLaterWidget)
     , mInfo(info)
 {
     setWindowTitle(i18nc("@title:window", "Send Later"));
@@ -30,7 +31,6 @@ SendLaterDialog::SendLaterDialog(SendLaterInfo *info, QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
 
     auto sendLaterWidget = new QWidget(this);
-    mSendLaterWidget = new Ui::SendLaterWidget;
     mSendLaterWidget->setupUi(sendLaterWidget);
 
     auto w = new QWidget(this);
