@@ -2,8 +2,7 @@
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
-#ifndef MESSAGECORE_STRINGUTIL_H
-#define MESSAGECORE_STRINGUTIL_H
+#pragma once
 
 #include "kmime/kmime_header_parsing.h"
 #include "kmime/kmime_message.h"
@@ -18,7 +17,7 @@ namespace KMime
 namespace Types
 {
 struct Address;
-typedef QVector<Address> AddressList;
+using AddressList = QVector<Address>;
 class Mailbox;
 }
 namespace Headers
@@ -98,7 +97,7 @@ enum Display { DisplayNameOnly, DisplayFullAddress };
 enum Link { ShowLink, HideLink };
 
 /**
- * Used to determine if the address field should be expandable/collapsable.
+ * Used to determine if the address field should be expandable/collapsible.
  */
 enum AddressMode { ExpandableAddresses, FullAddresses };
 
@@ -185,7 +184,7 @@ Q_REQUIRED_RESULT MESSAGECORE_EXPORT QString formatQuotePrefix(const QString &wi
 Q_REQUIRED_RESULT MESSAGECORE_EXPORT QString cleanFileName(const QString &fileName);
 
 /**
- * Removes the forward and reply markes (e.g. Re: or Fwd:) from a @p subject string.
+ * Removes the forward and reply marks (e.g. Re: or Fwd:) from a @p subject string.
  * Additional markers to act on can be specified in the MessageCore::GlobalSettings
  * object.
  */
@@ -217,7 +216,8 @@ Q_REQUIRED_RESULT MESSAGECORE_EXPORT QString replySubject(KMime::Message *msg);
       @p str is replaced by @p newPrefix.
   **/
 Q_REQUIRED_RESULT MESSAGECORE_EXPORT QString replacePrefixes(const QString &str, const QStringList &prefixRegExps, bool replace, const QString &newPrefix);
+
+Q_REQUIRED_RESULT MESSAGECORE_EXPORT QString normalize(QStringView str);
 }
 }
 
-#endif
