@@ -6,8 +6,7 @@
  *
  *******************************************************************************/
 
-#ifndef MESSAGELIST_CORE_ITEM_P_H
-#define MESSAGELIST_CORE_ITEM_P_H
+#pragma once
 
 #include "core/item.h"
 
@@ -38,9 +37,7 @@ public:
     {
     }
 
-    virtual ~ItemPrivate()
-    {
-    }
+    virtual ~ItemPrivate() = default;
 
     /**
      * Implements "in the middle" insertions of child items.
@@ -494,4 +491,3 @@ public:
 } // namespace Core
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_ITEM_P_H
