@@ -8,18 +8,18 @@
 #include "searchcollectionindexingwarning.h"
 #include "messagelist_debug.h"
 
-#include <AkonadiCore/cachepolicy.h>
-#include <AkonadiCore/collectionfetchjob.h>
-#include <AkonadiCore/collectionfetchscope.h>
-#include <AkonadiCore/collectionstatistics.h>
-#include <AkonadiCore/entityhiddenattribute.h>
-#include <AkonadiCore/persistentsearchattribute.h>
+#include <Akonadi/CachePolicy>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/CollectionStatistics>
+#include <Akonadi/EntityHiddenAttribute>
+#include <Akonadi/PersistentSearchAttribute>
 
 #include <PimCommon/PimUtil>
 
 #include <KLocalizedString>
 
-#include <AkonadiSearch/PIM/indexeditems.h>
+#include <PIM/indexeditems.h>
 
 using namespace MessageList::Core;
 
@@ -36,9 +36,7 @@ SearchCollectionIndexingWarning::SearchCollectionIndexingWarning(QWidget *parent
     setMessageType(Information);
 }
 
-SearchCollectionIndexingWarning::~SearchCollectionIndexingWarning()
-{
-}
+SearchCollectionIndexingWarning::~SearchCollectionIndexingWarning() = default;
 
 Akonadi::CollectionFetchJob *SearchCollectionIndexingWarning::fetchCollections(const Akonadi::Collection::List &cols, bool recursive)
 {
