@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,7 +20,6 @@
 #include <QCompleter>
 #include <QContextMenuEvent>
 #include <QMenu>
-#include <QPointer>
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QStringListModel>
@@ -49,9 +48,7 @@ SearchLineStatus::SearchLineStatus(QWidget *parent)
     connect(FilterSavedManager::self(), &FilterSavedManager::activateFilter, this, &SearchLineStatus::slotActivateFilter);
 }
 
-SearchLineStatus::~SearchLineStatus()
-{
-}
+SearchLineStatus::~SearchLineStatus() = default;
 
 void SearchLineStatus::keyPressEvent(QKeyEvent *e)
 {
