@@ -12,10 +12,10 @@
 #include <messagelist/enums.h>
 #include <messagelist/view.h>
 
-#include <AkonadiCore/Item>
-#include <collection.h>
-#include <kmime/kmime_message.h>
-#include <messagelist_export.h>
+#include "messagelist_export.h"
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <KMime/KMimeMessage>
 
 class KXMLGUIClient;
 class QAbstractItemModel;
@@ -138,7 +138,7 @@ public:
      * messageTypeFilter can be used to restrict the selection to only certain message types.
      *
      * existingSelectionBehaviour specifies how the existing selection
-     * is manipulated. It may be cleared, expanded or grown/shrinked.
+     * is manipulated. It may be cleared, expanded or grown/shrunk.
      *
      * If centerItem is true then the specified item will be positioned
      * at the center of the view, if possible.
@@ -158,7 +158,7 @@ public:
      * messageTypeFilter can be used to restrict the selection to only certain message types.
      *
      * existingSelectionBehaviour specifies how the existing selection
-     * is manipulated. It may be cleared, expanded or grown/shrinked.
+     * is manipulated. It may be cleared, expanded or grown/shrunk.
      *
      * If loop is true then the "previous" algorithm will restart from the end
      * of the list if the beginning is reached, otherwise it will just stop returning false.
@@ -439,8 +439,8 @@ private:
 
     bool eventFilter(QObject *obj, QEvent *event) override;
 
-    class Private;
-    Private *const d;
+    class PanePrivate;
+    std::unique_ptr<PanePrivate> const d;
 };
 } // namespace MessageList
 
