@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMCHECKSIGNATUREJOBTEST_H
-#define DKIMCHECKSIGNATUREJOBTEST_H
+#pragma once
 
 #include <QObject>
 #include <QtCrypto>
@@ -26,4 +25,3 @@ private:
     QCA::Initializer *mQcaInitializer = nullptr;
 };
 
-#endif // DKIMCHECKSIGNATUREJOBTEST_H
