@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef DKIMAUTHENTICATIONSTATUSINFO_H
-#define DKIMAUTHENTICATIONSTATUSINFO_H
+#pragma once
 
 #include "messageviewer_private_export.h"
 #include <QDebug>
@@ -75,4 +74,3 @@ Q_DECLARE_METATYPE(MessageViewer::DKIMAuthenticationStatusInfo)
 Q_DECLARE_TYPEINFO(MessageViewer::DKIMAuthenticationStatusInfo::AuthStatusInfo, Q_MOVABLE_TYPE);
 MESSAGEVIEWER_EXPORT QDebug operator<<(QDebug d, const MessageViewer::DKIMAuthenticationStatusInfo &t);
 
-#endif // DKIMAUTHENTICATIONSTATUSINFO_H
