@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,7 +10,7 @@
 #include "dkimresultattribute.h"
 #include "messageviewer_dkimcheckerdebug.h"
 #include "settings/messageviewersettings.h"
-#include <AkonadiCore/AttributeFactory>
+#include <Akonadi/AttributeFactory>
 
 using namespace MessageViewer;
 DKIMManager::DKIMManager(QObject *parent)
@@ -21,9 +21,7 @@ DKIMManager::DKIMManager(QObject *parent)
     Akonadi::AttributeFactory::registerAttribute<MessageViewer::DKIMResultAttribute>();
 }
 
-DKIMManager::~DKIMManager()
-{
-}
+DKIMManager::~DKIMManager() = default;
 
 DKIMManager *DKIMManager::self()
 {
