@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,9 +19,7 @@ HeaderStyleInterface::HeaderStyleInterface(MessageViewer::HeaderStylePlugin *hea
 {
 }
 
-HeaderStyleInterface::~HeaderStyleInterface()
-{
-}
+HeaderStyleInterface::~HeaderStyleInterface() = default;
 
 QList<KToggleAction *> HeaderStyleInterface::action() const
 {
@@ -35,7 +33,7 @@ void HeaderStyleInterface::addHelpTextAction(QAction *act, const QString &text)
 
 void HeaderStyleInterface::addActionToMenu(KActionMenu *menu, QActionGroup *actionGroup)
 {
-    for (KToggleAction *taction : qAsConst(mAction)) {
+    for (KToggleAction *taction : std::as_const(mAction)) {
         menu->addAction(taction);
         actionGroup->addAction(taction);
     }
