@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSSAGEVIEWER_TESTCSSHELPER_H
-#define MESSSAGEVIEWER_TESTCSSHELPER_H
+#pragma once
 
 #include <MessageViewer/CSSHelper>
 
@@ -23,4 +22,3 @@ public:
 }
 }
 
-#endif // MESSSAGEVIEWER_TESTCSSHELPER_H
