@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -10,9 +10,7 @@ using namespace MessageViewer;
 class MessageViewer::MessageViewerCheckBeforeDeletingPluginPrivate
 {
 public:
-    MessageViewerCheckBeforeDeletingPluginPrivate()
-    {
-    }
+    MessageViewerCheckBeforeDeletingPluginPrivate() = default;
     bool mIsEnabled = true;
 };
 
