@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ class TestWebEngineScamDetection : public QWidget
     Q_OBJECT
 public:
     explicit TestWebEngineScamDetection(QWidget *parent = nullptr);
-    ~TestWebEngineScamDetection();
+    ~TestWebEngineScamDetection() override;
 
     void setHtml(const QString &html);
 private Q_SLOTS:
@@ -37,7 +37,7 @@ class ScamDetectionWebEngineTest : public QObject
     Q_OBJECT
 public:
     explicit ScamDetectionWebEngineTest(QObject *parent = nullptr);
-    ~ScamDetectionWebEngineTest();
+    ~ScamDetectionWebEngineTest() override;
 private Q_SLOTS:
     void scamtest_data();
     void scamtest();
