@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -15,19 +15,14 @@
 
 #include <QJsonDocument>
 #include <QNetworkAccessManager>
-#include <QNetworkConfigurationManager>
 
 using namespace MessageViewer;
 class MessageViewer::ScamExpandUrlJobPrivate
 {
 public:
-    ScamExpandUrlJobPrivate()
-    {
-    }
+    ScamExpandUrlJobPrivate() = default;
 
-    ~ScamExpandUrlJobPrivate()
-    {
-    }
+    ~ScamExpandUrlJobPrivate() = default;
 
     QNetworkAccessManager *mNetworkAccessManager = nullptr;
 };
@@ -48,7 +43,7 @@ ScamExpandUrlJob::~ScamExpandUrlJob() = default;
 
 void ScamExpandUrlJob::expandedUrl(const QUrl &url)
 {
-    if (!PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
+    if (!PimCommon::NetworkManager::self()->isOnline()) {
         PimCommon::BroadcastStatus::instance()->setStatusMsg(i18n("No network connection detected, we cannot expand url."));
         deleteLater();
         return;
