@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "testmailmboxwebengine.h"
 
-#include <KMime/Content>
 #include <KActionCollection>
+#include <KMime/Content>
 #include <QApplication>
+#include <QDebug>
 #include <QFile>
 #include <QVBoxLayout>
-#include <QDebug>
 
 #include <MessageViewer/MailWebEngineView>
 #include <MessageViewer/Viewer>
@@ -19,17 +19,14 @@
 TestMailMBoxWebEngine::TestMailMBoxWebEngine(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vbox = new QVBoxLayout(this);
-    MessageViewer::Viewer *viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(
-                                                                  this));
+    auto vbox = new QVBoxLayout(this);
+    auto viewer = new MessageViewer::Viewer(nullptr, nullptr, new KActionCollection(this));
     vbox->addWidget(viewer);
     viewer->setMessage(readAndParseMail(QStringLiteral("html.mbox")));
     viewer->setPluginName(QStringLiteral("longheaderstyleplugin"));
 }
 
-TestMailMBoxWebEngine::~TestMailMBoxWebEngine()
-{
-}
+TestMailMBoxWebEngine::~TestMailMBoxWebEngine() = default;
 
 KMime::Message::Ptr TestMailMBoxWebEngine::readAndParseMail(const QString &mailFile)
 {
@@ -49,7 +46,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    auto *testWebEngine = new TestMailMBoxWebEngine;
+    auto testWebEngine = new TestMailMBoxWebEngine;
     testWebEngine->show();
     const int ret = app.exec();
     return ret;
