@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef TESTWEBENGINEACCESSKEY_H
-#define TESTWEBENGINEACCESSKEY_H
+#pragma once
 
 #include <QWidget>
 namespace WebEngineViewer
@@ -31,7 +30,6 @@ private Q_SLOTS:
     void slotShowAccessKey();
 
 private:
-    WebEngineViewer::MailWebEngineView *mTestWebEngine;
+    WebEngineViewer::MailWebEngineView *mTestWebEngine = nullptr;
 };
 
-#endif // TESTWEBENGINEACCESSKEY_H
