@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #pragma once
 
 #include "messageviewer_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <KMime/Message>
 #include <QObject>
 
@@ -54,7 +54,7 @@ Q_SIGNALS:
     void activatePlugin(MessageViewer::ViewerPluginInterface *);
 
 private:
-    ViewerPluginInterfacePrivate *const d;
+    std::unique_ptr<ViewerPluginInterfacePrivate> const d;
 };
 }
 
