@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef SHOWNEXTMESSAGEWIDGET_H
-#define SHOWNEXTMESSAGEWIDGET_H
+#pragma once
 
 #include "messageviewer_private_export.h"
 #include <QWidget>
@@ -25,9 +24,8 @@ Q_SIGNALS:
     void showPreviousMessage();
 
 private:
-    QPushButton *mNextMessage = nullptr;
-    QPushButton *mPreviousMessage = nullptr;
+    QPushButton *const mNextMessage;
+    QPushButton *const mPreviousMessage;
 };
 }
 
-#endif // SHOWNEXTMESSAGEWIDGET_H
