@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ CryptoBodyPartMemento::CryptoBodyPartMemento()
 {
 }
 
-CryptoBodyPartMemento::~CryptoBodyPartMemento()
-{
-}
+CryptoBodyPartMemento::~CryptoBodyPartMemento() = default;
 
 bool CryptoBodyPartMemento::isRunning() const
 {
