@@ -15,8 +15,8 @@
 #include "objecttreeparser.h"
 
 #include "bodypartformatterfactory.h"
-#include "nodehelper.h"
 #include "messagepart.h"
+#include "nodehelper.h"
 #include "partnodebodypart.h"
 
 #include "mimetreeparser_debug.h"
@@ -161,7 +161,7 @@ MessagePartPtr ObjectTreeParser::processType(KMime::Content *node, ProcessResult
 MessagePart::Ptr ObjectTreeParser::parseObjectTreeInternal(KMime::Content *node, bool onlyOneMimePart)
 {
     if (!node) {
-        return MessagePart::Ptr();
+        return {};
     }
 
     // reset pending async jobs state (we'll rediscover pending jobs as we go)
@@ -260,8 +260,7 @@ void ProcessResult::setNeverDisplayInline(bool display)
 
 void ProcessResult::adjustCryptoStatesOfNode(const KMime::Content *node) const
 {
-    if ((inlineSignatureState() != KMMsgNotSigned)
-        || (inlineEncryptionState() != KMMsgNotEncrypted)) {
+    if ((inlineSignatureState() != KMMsgNotSigned) || (inlineEncryptionState() != KMMsgNotEncrypted)) {
         mNodeHelper->setSignatureState(node, inlineSignatureState());
         mNodeHelper->setEncryptionState(node, inlineEncryptionState());
     }
