@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include "mimetreeparser_export.h"
 #include <QObject>
 #include <QStringList>
-
+#include <memory>
 namespace MimeTreeParser
 {
 class AttachmentTemporaryFilesDirsPrivate;
@@ -38,7 +38,7 @@ private Q_SLOTS:
     void slotRemoveTempFiles();
 
 private:
-    AttachmentTemporaryFilesDirsPrivate *const d;
+    std::unique_ptr<AttachmentTemporaryFilesDirsPrivate> const d;
 };
 }
 
