@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ public:
     explicit TemplateParserEmailAddressRequesterBase(QWidget *parent = nullptr);
     ~TemplateParserEmailAddressRequesterBase() override;
 
-    virtual Q_REQUIRED_RESULT QString text() const;
+    Q_REQUIRED_RESULT virtual QString text() const;
     virtual void setText(const QString &str);
     virtual void clear();
 Q_SIGNALS:
