@@ -1,15 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef TEMPLATEPARSER_TEMPLATESUTIL_P_H
-#define TEMPLATEPARSER_TEMPLATESUTIL_P_H
+#pragma once
 
 #include "templateparser_private_export.h"
 #include <QString>
-class QString;
 #include <QStringList>
 namespace TemplateParser
 {
@@ -21,4 +19,3 @@ TEMPLATEPARSER_TESTS_EXPORT Q_REQUIRED_RESULT QString removeSpaceAtBegin(const Q
 }
 }
 
-#endif
