@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class WebHitTestResultTest : public QObject
     Q_OBJECT
 public:
     explicit WebHitTestResultTest(QObject *parent = nullptr);
-    ~WebHitTestResultTest();
+    ~WebHitTestResultTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldAssignPosAndUrl();
