@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,6 +8,7 @@
 
 #include "webengineviewer_export.h"
 #include <QObject>
+#include <memory>
 namespace WebEngineViewer
 {
 class BackOffModeManagerPrivate;
@@ -33,7 +34,7 @@ public Q_SLOTS:
     void slotTimerFinished();
 
 private:
-    BackOffModeManagerPrivate *const d;
+    std::unique_ptr<BackOffModeManagerPrivate> const d;
 };
 }
 
