@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class SearchFullHashGui : public QWidget
     Q_OBJECT
 public:
     explicit SearchFullHashGui(QWidget *parent = nullptr);
-    ~SearchFullHashGui();
+    ~SearchFullHashGui() override;
 private Q_SLOTS:
     void slotCheckUrl();
     void slotGetResult(WebEngineViewer::CheckPhishingUrlUtil::UrlStatus result);
