@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -30,9 +30,7 @@ TestDndWebEngine::TestDndWebEngine(QWidget *parent)
     vbox->addWidget(edit);
 }
 
-TestDndWebEngine::~TestDndWebEngine()
-{
-}
+TestDndWebEngine::~TestDndWebEngine() = default;
 
 int main(int argc, char *argv[])
 {
