@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ class TestSelectionChangedEngine : public QWidget
     Q_OBJECT
 public:
     explicit TestSelectionChangedEngine(QWidget *parent = nullptr);
-    ~TestSelectionChangedEngine();
+    ~TestSelectionChangedEngine() override;
 private Q_SLOTS:
     void slotSelectionChanged();
 
