@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ using namespace WebEngineViewer;
 class WebEngineViewer::NetworkUrlInterceptorPrivate
 {
 public:
-    NetworkUrlInterceptorPrivate()
-    {
-    }
+    NetworkUrlInterceptorPrivate() = default;
 
     void addInterceptor(NetworkPluginUrlInterceptorInterface *interceptor);
     void interceptRequest(QWebEngineUrlRequestInfo &info);
@@ -55,10 +53,7 @@ NetworkUrlInterceptor::NetworkUrlInterceptor(QObject *parent)
 {
 }
 
-NetworkUrlInterceptor::~NetworkUrlInterceptor()
-{
-    delete d;
-}
+NetworkUrlInterceptor::~NetworkUrlInterceptor() = default;
 
 void NetworkUrlInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info)
 {
