@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -71,7 +71,7 @@ static QString linkElementKey(const WebEngineViewer::WebEngineAccessKeyAnchor &e
         }
         return linkKey;
     }
-    return QString();
+    return {};
 }
 
 static void
